#
# spec file for package ignition
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ignition
Version:        2.3.0
Release:        bp153.1.75
Summary:        First boot installer and configuration tool
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/coreos/ignition
Source:         %{name}-%{version}.tar.xz
Patch2:         0002-allow-multiple-mounts-of-same-device.patch
Requires:       dracut
Recommends:     /sbin/mkfs.btrfs
Recommends:     /sbin/mkfs.ext4
Recommends:     /sbin/mkfs.vfat
Recommends:     /sbin/mkfs.xfs
Recommends:     /sbin/mkswap
Recommends:     /sbin/udevadm
Recommends:     /usr/sbin/groupadd
Recommends:     /usr/sbin/sgdisk
Recommends:     /usr/sbin/useradd
Recommends:     /usr/sbin/usermod
Suggests:       /sbin/mdadm
BuildRequires:  dracut
BuildRequires:  libblkid-devel
BuildRequires:  golang(API) >= 1.12

%description
Ignition is an utility to manipulate disks and configuration files
during the initramfs. This includes partitioning disks, formatting
partitions, writing files (regular files, systemd units, etc.), and
creating users.
On first boot, Ignition reads its configuration from a source of truth
(remote URL, network metadata service, hypervisor bridge, etc.) and
applies the configuration.

%prep
%setup -q
%patch2 -p1

%build
sed -i -e 's|go build -ldflags|go build -buildmode=pie -ldflags|g' build
env VERSION=%{version} GLDFLAGS='-X github.com/coreos/ignition/v2/internal/distro.selinuxRelabel=false -X github.com/coreos/ignition/v2/internal/distro.writeAuthorizedKeysFragment=false ' bash -x ./build

%install
install -d %{buildroot}%{_prefix}/lib/dracut/modules.d/30ignition
install -p -m 0755 bin/*/ignition %{buildroot}%{_prefix}/lib/dracut/modules.d/30ignition
install -d -p %{buildroot}%{_bindir}
install -p -m 0755 bin/*/ignition-validate %{buildroot}%{_bindir}

%files
%license LICENSE
%doc README.md doc
%{_prefix}/lib/dracut/modules.d/30ignition
%{_bindir}/ignition-validate

%changelog
* Mon May 11 2020 kukuk@suse.de
- Update to version 2.3.0:
  * news: add notes for 2.3.0
  * config/v3_2_experimental: update all copyright dates
  * doc/configuration-*: update for new spec
  * tests: stabilize spec 3.1.0
  * *: update for new experimental spec
  * config/v3_2_experimental: set up package
  * config/v3_2_experimental: copy from config/v3_1
  * config/v3_1_experimental: mark stable
  * doc/development: update spec stabilization instructions
  * config: rename function for clarity
  * tests: bump invalid 2.x experimental version to match spec2x branch
  * config/v3_1_experimental: add some missing version tests
  * config/v3_1/translate: fix package name
  * doc/migrating-configs: update for 3.1.0
  * resource/url: allow compression in data URLs
  * doc/migrating-configs: mention spec 2.4.0
  * validate: accept any supported config version
  * exec: drop validate.go
  * doc/migrating-configs: put newest version first
  * Add SHA-256 reference in the docs
  * Add SHA-256 support for file verification
  * ci: run blackbox tests in CoreOS CI
  * Send ssh_authorized keys info into the journald log
  * Update go-systemd with the systemd module
  * Send a message to the systemd journal if a user config is provided
  * tests: add positive tests for resource compression
  * spec: unify resource fetching type
  * doc: clarify wording of files.*.verification.hash
  * vendor: refresh after gomod changes
  * gomod: update to go-systemd v22
  * stages: fix package names
  * providers/packet: override Accept header fetching instance metadata
  * resource/url: allow caller-specified headers to override defaults
  * Allow to specify HTTP headers for fetching configs and files
* Wed Mar 25 2020 kukuk@suse.de
- Update to version 2.2.1:
  * news: add notes for 2.2.1
  * providers/qemu: fix default to fwcfg
  * doc/development: remember to bump Accept header during spec bumps
- Remove 0001-Support-more-architectures.patch:
  Patch added upstream
* Tue Mar 24 2020 Ignaz Forster <iforster@suse.com>
- Add 0001-Support-more-architectures.patch:
  Allow builing on i586 (and other architectures) again
* Tue Mar 24 2020 kukuk@suse.de
- Update to version 2.2.0:
  * news: add notes for 2.2.0
  * Fix ignition config for the instantiated unit test
  * Fix enabling systemd instantiated services
  * providers/qemu: support Ignition block device on s390x and ppc64le
  * blkid: Explicitly use C int variable for numParts
  * tests: don't panic after failing to run Ignition
  * platform: sort providers
  * ci: migrate to new coreos-ci project
  * OWNERS: add OWNERS file
  * Add Exoscale provider
  * docs: minor fixes to platforms page
  * ci: hook up to CoreOS CI
  * providers/vultr: Add Vultr provider
  * Throw error if SSH keys could not be written
  * stages/files: don't relabel /home and /root symlinks
- Drop 0001-Throw-error-if-SSH-keys-could-not-be-written.patch
- Added explicit Recommends for helper applications
  [boo#1167289]
* Tue Jan 21 2020 Ignaz Forster <iforster@suse.com>
- Do not use SSH keys fragments, those are not supported by
  openSUSE. [boo#1161265]
* Tue Jan 14 2020 Ignaz Forster <iforster@suse.com>
- Add 0002-allow-multiple-mounts-of-same-device.patch:
  Allow mounting a device multiple times, e.g. to mount several
  subvolumes from a Btrfs device or bind mounting the device to
  multiple places, by also adding the path to the key.
  [Workaround for gh#coreos/ignition#890]
* Wed Jan  8 2020 Ignaz Forster <iforster@suse.com>
- Add 0001-Throw-error-if-SSH-keys-could-not-be-written.patch:
  Don't silently ignore if the SSH key could not be written
  [boo#1159232]
* Mon Dec 23 2019 iforster@suse.de
- Update to version 2.1.1:
  * stages/files: don't relabel /home and /root symlinks
  * tests/filesystems: fix error handling
  * blackbox tests: don't swallow errors
  * log: use os.ProcessState.ExitCode instead of unix
  * travis: bump min go to 1.12
  * news: add notes for 2.1.1
  * readme: fix links, add validation container docs
  * Dockerfile: add dockerfile for ignition-validate
  * news: add news for v2.1.0
  * README.md: add details about dracut and branches here
  * doc/operator-notes: simplify SELinux section
  * mount: also relabel mount points
  * util: factor out FindFirstMissingDirForFile function
  * files: perform relabeling from initrd
  * doc/examples: Make example file path valid
  * Rework fetch/resource to automatically append required headers
* Wed Nov 20 2019 iforster@suse.de
- Update to version 2.0.1+git20191112.a924dd7:
  * tests: remove unused partitions, dead code
  * internal,tests: abolish syscall package
  * vendor: include golang.org/x/sys/unix
  * providers: add ibmcloud
- turn off SELinux by default
* Thu Nov  7 2019 kukuk@suse.de
- Update to version 2.0.1+git20191106.809f44a:
  * Add test cases for file system mount options
  * Add translator for Filesystem struct
  * Document file system mount options
  * Implement file system mount options
  * providers: add initial zVM hypervisor support
  * travis: test on arm, use new ubuntu, cleanup
  * config/v3_1_exp/types: validate http(s) proxies
  * tests: remove unused stub for id
  * distro: turn on SELinux by default
  * Add filesystem mount options to schema
  * files/passwd: don't shell out to id
  * files/passwd: clean up repetitive code
  * providers/aliyun: Add aliyun
  * release-checklist: mention mantle cl branch for 0.x.y releases
  * config/v3*: don't warn on unset mode if appending
* Fri Sep 27 2019 kukuk@suse.de
- Update to version 2.0.1+git20190925.641ec6a:
  * selinux: use /run/systemd/relabel-extra.d for etc
  * resource/url: Don't use a tmpfile in FetchToBuffer
  * resource/url: use only needed ifaces in fetchFrom*
  * resource/url: make FetchFrom* private
  * Add a `fetch` stage
  * build: Add `make install`
  * tests: fix bb tests for size/start 0
  * Continue on empty GPT partition label
  * files/selinux: deglob user/group related paths
  * stages/files: relabel masking symlinks for systemd
  * engine: Write `/run/ignition.json` atomically
  * vendor: Add github.com/google/renameio
  * stages/filesystems: drop stray debug print
  * doc/supported-platforms: mention qemu version requirements
  * Source build file correctly
  * resource/url: update schema version in Accept header
  * fix check path mount
- Drop 0001-Continue-on-empty-GPT-partition-label.patch: Added
  upstream
* Mon Sep  2 2019 iforster@suse.de
- Update to version 2.0.1+git20190802.d523754:
  * main: log stage at startup
- Add 0001-Continue-on-empty-GPT-partition-label.patch
* Fri Jul 26 2019 kukuk@suse.de
- Update to version 2.0.1+git20190725.10b85d1:
  * release-checklist: add step to submit to bodhi
  * news: add news for v2.0.1
  * config/v*: run Node.Validate() as well
  * doc/getting-started: rm online validator section
  * providers/aws: get region after getting config.
  * providers: allow FetchConfig to mutate the fetcher
  * release-checklist: fix for new website and jenkins
* Thu Jun  6 2019 kukuk@suse.de
- Update to version 2.0.0+git20190603.0c1da80:
  * news: update for v2.0.0
  * build*: use --always with git describe
  * vendor: switch to coreos/vcontext
  * config/validate: add tests for duplicate checking
  * build: export GOFLAGS so they get used
  * config/validate: add test for validation
  * config/validate: check for unused keys
  * internal/util/docs: update to use new validation
  * internal: update to use new validation code
  * config/validate: replace old validation with vcontext
  * config/v3*: update to use new validation functions
  * vendor: add vcontext
  * internal: create dev aliases in /run/ignition/ instead of /
  * Update hostname example
  * tests/*: rename bb tests
  * release-checklist: split out 0.x and 2.x+ bits
* Thu May  2 2019 kukuk@suse.de
- Update to version 2.0.0~beta+git20190429.1eeb201:
  * build_releases: update for using go mod
  * news: add news for v2.0.0-beta
  * doc: mv spec 3.1.0 -> 3.1.0-experimental
  * contributing.md: add pointer to development guide
  * doc/operator-notes: add section on config merging
  * test: turn on docs checking
  * doc/migrating-configs.md: update for spec 3.0.0
  * doc/development.md: update doc for spec 3.0.0
  * doc/getting-started.md: update for spec 3.0.0
  * doc/examples.md: update for spec 3.0.0
* Thu Apr 25 2019 kukuk@suse.de
- Update to version 0.30.0+git20190424.9212ea6:
  * doc: add docs for existing link behavior
  * tests: add test for matching links
  * tests: fix test runner to link in the correct root
  * stages/files: do not fail if links are correct
  * tests/positive: test hardlinking to symlinks
  * tests/validator: use os.Lstat() not os.Stat()
  * config/*/types/storage: fail on hardlinked dirs
* Tue Apr 23 2019 kukuk@suse.de
- Update to version 0.30.0+git20190417.ccc74c4:
  * doc/config-v3_*: Add notes about uniqueness
* Mon Apr 15 2019 kukuk@suse.de
- Update to version 0.30.0+git20190411.205ae79:
  * providers/vmware: update for new vmware library
  * vendor: update to use vmware libraries
  * tests: update code for google's uuid package
  * vendor: switch to github.com/google/uuid
  * vendor: bump go-semver to latest
  * vendor: update aws-sdk-go to latest tag
  * doc: Document new proxy configuration options
  * vendor: Add golang.org/x/net/http/httpproxy dep
  * tests: Initial positive/negative tests
  * engine: Update http client based on proxy config
  * schema: Add proxy config and properties
  * *: bump import path
  * platform: drop "pxe"
  * doc: add documentation for 3.1.0-experimental spec
  * tests: turn on 3.1.0-experimental tests
  * *: switch to using 3.1.0-experimental everywhere
  * tests: don't fail on 3.1.0-experimental
  * config: add v3.1.0-experimental spec
  * tests/runner: use generic parse
  * providers/util: use generic parse
  * internal/engine: use generic parse
  * tests: add test for directory correction
  * doc/spec-3_0: clarify behavior with overwrite
  * stages/file: fail if relabeling and no restorecon
  * stages/files: allow directory matching
  * config/v3_0/types: add files verification tests
  * config/v3_0/types/file: add more validation
  * config/helpers: make StrToPtr strict
  * doc/spec-3_0: clarify overwrite behavior
  * stages/files: refactor overwrite handling
  * config/v3_0: disallow overwrite and nil source
  * config: validate fs entries dont use symlinks
  * platform: drop compat alias for "ec2" platform ID
  * config/shared/errors: drop unused errors
  * doc/spec-v3_0: remove deprecated size and start
  * tests: add test for file conflicts
  * stages/files: check that files dont conflict
  * config: remove partition start and size
  * internal: don't use partitions.{size,start}
  * tests: change partitioning bb to use MiB
  * build_blackbox_tests: fix for go mod
  * stages/files: fix unit relabeling to exclude DestDir
  * Fix configspec link to remove `-experimental`
  * doc/spec-v3_0: update to not be -experimental
  * tag_release: allow -suffixes on tags
  * doc/spec-v3_0: remove docs on removed field
  * doc: drop -experimental from spec filename
  * news: add news for 2.0.0-alpha
  * tests/positive/general: use hashes from server
  * tests: make servers generate their own hashes
  * *: stablize spec 3.0.0
  * stages/files: fix relabel path to be relative to sysroot
  * tests: add bb test for invalid merged configs
  * exec/engine: validate merged config before use
  * tests/blackbox: make runner print config
  * config/types: call IgnoreDuplicates correctly
  * config: test to ensure config type is valid
  * config/types: de-pointer config.ignition.replace
  * config/merge: add tests
  * config: replace config appending with merging
  * config/v3_0_exp: rename config.append to merge
  * config: rework schema for better merging
  * *: rename ec2 -> aws and gce -> gcp
  * stages/files: Also relabel subuid/subgid files
  * doc/config-spec: drop passwd.users.create
  * config: drop passwd.users.create
  * config/validate: allow dups on some fields
  * config/validate_test: add tests for detecting dups
  * doc/config-v3_0_exp: add doc for new append logic
  * config/v3_0_exp: reject duplicate partition labels
  * config/v3_0_exp: require partition label or number
  * config/validate: validate no duplicates exist
  * config/v3_0_exp/types: implement Key() for types
  * tests/files: add test appending to existing file
  * tests: apply mode/owner in bb test runner input
  * config/v3_0_exp/types: rework storage.files.append
  * config: refactor
  * *: use config/ver instead of internal/config
  * config: move json schema to be with its types
  * test: don't validate docs
  * tests/negative/files: add ForceFileCreationNoOverwrite
  * *: default file.overwrite config option to false
  * tests/positive/passwd: add test UseAuthorizedKeysFile
  * tests/*: expose env vars through Test.Env
  * internal/*: drop merging authorized_keys.d into authorized_keys
  * vendor: switch to go modules
  * MAINTAINERS: update
* Mon Mar 18 2019 Ignaz Forster <iforster@suse.com>
- Copy binary to dracut module directory as required by
  https://github.com/coreos/ignition-dracut/commit/b11553f9e2b530fbbb5a2504bc72b364829c879c
* Mon Mar  4 2019 kukuk@suse.de
- Update to version 0.30.0+git20190301.2ce015b:
  * tests: add test ensuring correct ordering of nodes
  * tests: move failing tests to negative
  * stages/files: sort entries by resolved depth
  * Fix function comments based on best practices from Effective Go
  * tests: add bb test for mounting with sylminks
  * stages/mount: fail if mount paths involve symlinks
  * internal/exec/util: make SplitPath public
  * config/translate: add unit tests
  * config/translate: add reflection based translator
  * internal/distro: use relative paths
  * exec/util/passwd: rename authorized_keys.d fragment to "ignition"
* Wed Feb 27 2019 kukuk@suse.de
- Update to version 0.30.0+git20190225.7de027b:
  * oem: add metal oem
  * internal/exec: use nonzero default file permissions
  * *: drop OEM terminology
  * tests: drop OEMLookaside type
  * *: drop OEM URI support
  * tests/validator: show formatted os.FileMode in validateMode error
  * doc/configuration-v3_0_exp: update with fs changes
  * tests: refactor bb tests, add mount/umount stages
  * exec/stages: add mount and umount stages
  * tests/*: update bb tests for new fs semantics
  * exec/*: rework files and filesystems
  * validate/report: add helpers to cut verbosity
  * engine: log configs on failure and fetched urls
  * engine: clear highlights before logging reports
  * internal/exec: log hashes of configs not configs
* Tue Feb 19 2019 kukuk@suse.de
- Update to version 0.30.0+git20190215.cc767cc:
  * vendor: remove unused dependency go4.org
  * config: replace go4's errorutil with own impl
* Fri Feb 15 2019 kukuk@suse.de
- Update to version 0.30.0+git20190206.aad24ad:
  * doc/development: add note to run individual blackbox tests
  * tests/types: add comments on some members of Test
  * internal/*: drop support for default.ign config files
* Wed Jan 30 2019 kukuk@suse.de
- Update to version 0.30.0+git20190124.fd1e703:
  * docs: fix stale link to config 2.x
* Mon Jan 14 2019 kukuk@suse.de
- Update to version 0.30.0+git20190111.96f8aae:
  * Replace cobra with built-in flag
  * *: drop networkd section
  * travis: bump min go version to 1.10.x
* Fri Jan 11 2019 kukuk@suse.de
- Update to version 0.30.0+git20190110.5a28cac:
  * docs: remove config 2.x, add config 3.0.0 spec doc
  * config/*: drop cloudinit support
  * config: rip out all v1, v2.x configs
  * tests: update all versions to 3.0.0-experimental
  * config: replace v2_4 with v3_0_exp
  * types/v2_4_exp: rename to 3_0_exp
  * tests/timeouts: fix concurrency panic
  * internal/oem: drop vagrant-virtualbox
  * internal/oem: drop noop OEMs
  * Rename `coreos.config.*` options to `ignition.config.*` to make options more distribution neutral
* Wed Dec 19 2018 kukuk@suse.de
- Update to version 0.30.0+git20181218.641adcb:
  * readme: add note about branching
  * release-checklist: correctly select GPG subkey ID
  * release-checklist: bump Fedora specfile
  * release-checklist: fix tag_release script name
  * news: add news for 0.30.0
  * doc/development: add "kind/release" label to release issues
  * test: skip backward compat tests with -test.short
  * tests/partitioning: add minversion to complex mb
  * tests: add -list flag to blackbox tests
  * stages/filesystems: parallelize creation
  * tests: add test for multiple data filesystems
  * internal/exec: increase default config fetch timeout
* Wed Dec 12 2018 kukuk@suse.de
- Update to version 0.29.1+git20181206.b1ab0b2:
  * news: add news for 0.29.1
  * tests: add bb test for symlink resolution
  * exec/util: use Lstat() for existance checks
  * exec/util: don't follow links for last path elem
  * internal/resource: use earlyrand
  * internal: add earlyrand
  * news: add news for 0.29.0
  * doc/migrating-configs: make link to doc relative
  * docs: update migrating config guide for 2.3.0
  * docs: add config spec for 2.4.0, update 2.3.0
  * tests: update to include 2.4.0-experimental
  * *: switch packages to use new experimental package
  * config/v2_4_experimental: add package
  * config/v2_3: update version to not be experimental
  * config/v2_3: change package statements to v2_3
  * config/2_3: move 2.3.0-exp to 2.3.0
  * schema: use mebibytes not megabytes for partitions
  * schema: fix incorrect case
  * docs/operator-notes: add notes about symlinks
  * tests: add bb tests for symlink resolution
  * internal/exec: fix util.JoinPath symlink handling
  * vendor: sync after glide updates
  * glide: update go-systemd to v18
  * glide: pin transitive deps for aws-sdk-go
  * tests/validator: be more verbose about links
  * internal/providers/packet: don't send success to packet from Ignition
  * resource: add support for ?versionId on s3:// URL download
  * config/v2.1+/link: allow relative paths for target
* Tue Oct 16 2018 kukuk@suse.de
- Update to version 0.28.0+git20181016.7785e61:
  * release-checklist: move to .github and drop front matter
  * stages/files: relabel files before systemd-sysctl
  * blkid: Compile with -Werror=implicit-function-declaration
  * config: Clarify semantics around certs
  * stages/disks: fix extraneous udevadm settle
  * glide: switch to tags where we can
  * stages/files: relabel /var/home and /var/roothome
  * tests: don't run files stage if disks failed
  * glide.*: remove subpackages
  * Revert "doc/development: update blackbox test instructions to low parallelism"
  * tests: workaround umount issues
  * docs/config-v2_3-exp: add sizeMB/startMB fields
  * tests: new tests for size-mb and start-mb
  * config/types/partition*: deprecate size/start
  * internal: updates for size-mb and start-mb
  * schema: add size-mb and start-mb to partitions
  * internal/*: fix go-vet formatting errors
  * build: clean before building
  * travis: bump go versions
  * doc/development: update blackbox test instructions to low parallelism
  * tests: refactor handling of root partition
  * tests: cleanup tests to use defer more
  * tests: cleanup extraneous testing.T's
  * tests: add a cancelation mechanism
  * build_blackbox_tests: only compile top level tests
  * release-checklist: explicitly merge the docs PR
  * config/*/append*: remove unused code
* Thu Sep  6 2018 kukuk@suse.de
- Initial version (0.28.0)
